# -*- coding: utf-8 -*- #
# Copyright 2014 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Commands for reading and manipulating HTTP health checks."""


from googlecloudsdk.calliope import base


@base.ReleaseTracks(
    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
class HttpHealthChecks(base.Group):
  """Read and manipulate HTTP health checks for load balanced instances."""


HttpHealthChecks.category = base.LOAD_BALANCING_CATEGORY

HttpHealthChecks.detailed_help = {
    'DESCRIPTION': """
        Read and manipulate legacy health checks that use the HTTP protocol.

        For more information about legacy health checks, see the
        [HTTP health checks documentation](https://cloud.google.com/load-balancing/docs/health-checks#legacy-health-checks).

        See also: [HTTP health checks API](https://cloud.google.com/compute/docs/reference/rest/v1/httpHealthChecks).
    """,
}
